@@ -5,7 +5,6 @@ import numpy as np
 from ..utils.constants import LOGConstants, TestConstants, JsonConstants
 import copy
 
-
 class BinoutData(object):
 
     def __init__(self, binout, logger, dynasaur_definitions, name):
@@ -205,14 +204,15 @@ class BinoutData(object):
                 if type(parameter_def[key]) is dict:  # step into recursion
                     self._get_data_from_json(parameter_def[key])
 
+
         else:  # data to obtain
             if "value" in json_object.keys():
-                return json_object["value"]
+                return
             elif "strain_stress" in json_object.keys():
-                return json_object["strain_stress"]
+                return
             elif "array" in json_object.keys():
                 self._defined_types.append(json_object['array'])
-                return json_object["array"]
+                return
             else:
                 print(json_object)
                 assert False
@@ -300,6 +300,8 @@ class BinoutData(object):
             return_function = self._check_id_in_binout("_disbout_part")
         elif self._name == "glstat":
             return_function = self._check_id_in_binout("_energy_global")
+        elif self._name == "abstat":
+            return_function = self._check_id_in_binout("_abstat")
         if not return_function[0]:
             self._logger.emit(LOGConstants.WARNING[0], "Not valid ID: " + return_function[1] +
                               ". Plese check your def file!")
