@@ -1,4 +1,3 @@
-import colorama
 from termcolor import colored
 
 from ..utils.constants import LOGConstants
@@ -11,7 +10,7 @@ class ConsoleLogger(object):
         :param:
         :return:
         """
-        colorama.init()
+        pass
 
     def _get_color_for_label(self, label):
         """
